# FireNext (Python)

FireNext is an offline database library.


## Authors

- [Mahfuz Salehin Moaz](https://www.github.com/almoaz)


## License
[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://github.com/almoaz/FireNext/blob/master/LICENSE)
    
## Version 
1.2.0

## Installation
```
pip install firenext
```

## About FireNext

FireNext works with two types of offline databases. Table type and Document type. Table type database name "NextTable" and document type database name "NextDatabase".

## NextTable

```
id                  name                   phone 
------------------------------------------------------------
18301               Mithila Mithi          019XXXXXXXX
------------------------------------------------------------
18302               Mahfuz Salehin         017XXXXXXXX
------------------------------------------------------------
18303               Al Moaz                016XXXXXXXX

```

## NextDatabase

```
USER
   |---18301
   |       |---name:Mithila Nisa
   |       |---id:18301
   |       |---phone:019XXXXXXXX
   |---18302
   |       |---name:Mahfuz Salehin
   |       |---id:18302
   |       |---phone:017XXXXXXXX
   |---18303
   |       |---name:Al Moaz
   |       |---id:18303
   |       |---phone:016XXXXXXXX

```


## Documentation

- [NextTable (Python)](https://github.com/almoaz/PyFireNext/blob/master/NextTable.md)
- [NextDatabase (Python)](https://github.com/almoaz/PyFireNext/blob/master/NextDatabase.md)



## Restiction

Please do not use these characters in your documents.
[Click for read](https://github.com/almoaz/PyFireNext/blob/master/Restriction.md)

## Having problems?

Please inform me via email at 'almuaz1998@gmail.com'


## Thanks

- Many thanks' python developers
- Special Thanks to Future Next Developers
